==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/GridDataCommittingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataSourceAggregatedResultDescriptionMetadata } from "./DataSourceAggregatedResultDescriptionMetadata";
import { GridDataCommittingEventArgsDescription } from "./GridDataCommittingEventArgsDescription";
/**
 * @hidden
 */
export let GridDataCommittingEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridDataCommittingEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (GridDataCommittingEventArgsDescriptionMetadata.a == null) {
                GridDataCommittingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridDataCommittingEventArgsDescriptionMetadata.c(GridDataCommittingEventArgsDescriptionMetadata.a);
            }
            if (a.j(GridDataCommittingEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(GridDataCommittingEventArgsDescriptionMetadata.a);
            DataSourceAggregatedResultDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("Changes", "Array:DataSourceAggregatedResultDescription:DataSourceAggregatedResult");
            a.item("CommitID", "Number:int");
        }
        static d(a) {
            GridDataCommittingEventArgsDescriptionMetadata.b(a);
            a.aa("GridDataCommittingEventArgs", () => new GridDataCommittingEventArgsDescription());
            a.z("GridDataCommittingEventArgs", GridDataCommittingEventArgsDescriptionMetadata.a);
        }
    }
    GridDataCommittingEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(GridDataCommittingEventArgsDescriptionMetadata, 'GridDataCommittingEventArgsDescriptionMetadata');
    GridDataCommittingEventArgsDescriptionMetadata.a = null;
    return GridDataCommittingEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/GridDataCommittingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataSourceAggregatedResultDescriptionMetadata } from "./DataSourceAggregatedResultDescriptionMetadata";
import { GridDataCommittingEventArgsDescription } from "./GridDataCommittingEventArgsDescription";
/**
 * @hidden
 */
export let GridDataCommittingEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridDataCommittingEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (GridDataCommittingEventArgsDescriptionMetadata.a == null) {
                GridDataCommittingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridDataCommittingEventArgsDescriptionMetadata.c(GridDataCommittingEventArgsDescriptionMetadata.a);
            }
            if (a.k(GridDataCommittingEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(GridDataCommittingEventArgsDescriptionMetadata.a);
            DataSourceAggregatedResultDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("Changes", "Array:DataSourceAggregatedResultDescription:DataSourceAggregatedResult");
            a.item("CommitID", "Number:int");
        }
        static d(a) {
            GridDataCommittingEventArgsDescriptionMetadata.b(a);
            a.ac("GridDataCommittingEventArgs", () => new GridDataCommittingEventArgsDescription());
            a.ab("GridDataCommittingEventArgs", GridDataCommittingEventArgsDescriptionMetadata.a);
        }
    }
    GridDataCommittingEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(GridDataCommittingEventArgsDescriptionMetadata, 'GridDataCommittingEventArgsDescriptionMetadata');
    GridDataCommittingEventArgsDescriptionMetadata.a = null;
    return GridDataCommittingEventArgsDescriptionMetadata;
})();
